@@ -1,3 +1,3 @@
-from morphcp.create_env import (create_lab)
+from morphcp.create_env import (create_lab, content_pack_processing)
 from morphcp.utils.helpers import (clear_session)
 from morphcp.logging.loghandler import (get_logger)
\ No newline at end of file
