@@ -13,6 +13,15 @@ import morphcp.utils.helpers as morph_util
 import morphcp.logging.loghandler as loghandler
 #from morph_util.vars import * 
 from morphcp.vars import *
+
+def success_status(json_response):
+    logger = loghandler.get_logger(__name__)
+    if json_response['success'] is True:
+        logger.info("Integration successfully created")
+    if json_response['success'] is False:
+        logger.error(f"Integration creation failed: {json_response['errors']}")
+
+
 def inject_groups():
     """
     The inject_groups function is used to create groups in the mo-laptop.
@@ -207,15 +216,51 @@ def inject_tasks():
     """
     logger = loghandler.get_logger(__name__)
     cl = RequestsApi()
-    cp_tasks_dir = os.path.join(contentpack_base_folder,os.environ.get("contentpack"),task_payload_folder,task_inject_filter_pattern)
-    files = glob.glob(cp_tasks_dir)
+    repos = cl.get(f"/api/options/codeRepositories").json()
+    cp_dir = os.path.join(contentpack_base_folder,os.environ.get("contentpack"),task_payload_folder,f"*{task_extract_filename}*")
+    files = glob.glob(cp_dir)
+    logger.debug(f"CP DIR: {cp_dir}")
+    logger.debug(f"Files for tasks: {files}")
+    # for file in files:
+    #     with open(file,'r') as f:
+    #         data = json.load(f)
+    #     f.close()
+    # if os.path.isdir(inputdir) is True:
+    #     logger.debug(f'{inputdir}/{task_payload_folder}/{task_extract_filename}')
+    #     files = glob.glob(f'{inputdir}/{task_payload_folder}/*{task_extract_filename}*')
     for file in files:
         with open(file,'r') as f:
             data = json.load(f)
         f.close()
-        payload = json.dumps(data)
-        resp = cl.post("/api/tasks", data = payload)
-        logger.debug(resp.json())
+        logger.debug(files)
+        if "ansibleGitId" in data['task']['taskOptions']:
+            if data['task']['taskOptions']['ansibleGitId'] != None:
+                resp = cl.get(f"/api/integrations?name={urllib.parse.quote(data['task']['taskOptions']['ansibleGitId'])}").json()
+                if resp['integrations'] == []:
+                    logger.warning("Ansible Git ID not found")
+                    logger.warning("Please create the integration first")
+                    logger.info("Skipping task creation")
+                else:
+                    data['task']['taskOptions']['ansibleGitId'] = resp['integrations'][0]['id']
+        elif data['task']['file'] != None:
+            if data['task']['file']['sourceType'] == "repository":
+                for repo in repos['data']:
+                    if data['task']['file']['repository']['name'] in repo['name']:
+                        data['task']['file']['repository']['id'] = repo['value']
+                    else:
+                        logger.debug("No match found")
+                        logger.debug(f"Task: {data['task']['file']['repository']['name']}")
+                        logger.debug(f"Repo: {repos}")
+        payload = json.dumps(data, indent=4)
+        logger.debug(f"Payload: {payload}")
+        resp = cl.post("/api/tasks", data = payload).json()
+        # if resp['success'] is True:
+        #     logger.info(f"Task {data['task']['name']} created")
+        # elif resp['success'] is False:
+        #     logger.warning(f"Task {data['task']['name']} failed to create")
+        #     logger.warning(json.dumps(resp))
+        success_status(resp)
+        
         
 def inject_optionlist():
     """
@@ -378,14 +423,10 @@ def inject_whitelabel():
 def inject_clouds():
     logger = loghandler.get_logger(__name__)
     cl = RequestsApi()
-
     def getgroups():
         groups = cl.get("/api/groups").json()
-        print(groups)
         group_id = groups["groups"][0]["id"]
-        
         return group_id
-    
     cp_dir = os.path.join(contentpack_base_folder,os.environ.get("contentpack"),cloud_payload_folder,cloud_pattern)
     files = glob.glob(cp_dir)
     for file in files:
@@ -393,15 +434,10 @@ def inject_clouds():
             data = json.load(f)
         f.close()
         json_object = json.dumps(data, indent=4)
-        #print(json_object)
-        
         data['zone']['groupId'] = getgroups()
-        #print(data)
         cloudid = cl.post("/api/zones", data = json_object).json()
         cloudid = cloudid["zone"]["id"]
-        print(cloudid)
         group_ids = cl.get("/api/groups").json()
-        print(group_ids)
         for x in group_ids["groups"]:
             group_id = x['id']
             payload = {
@@ -414,5 +450,20 @@ def inject_clouds():
                     }
             }
             payload = json.dumps(payload)
-            response = cl.put(f"/api/groups/{group_id}/update-zones", data = payload).json()
-            print(response)
+            resp = cl.put(f"/api/groups/{group_id}/update-zones", data = payload).json()
+            logger.debug(resp)
+            success_status(resp)
+
+def inject_integrations():
+    logger = loghandler.get_logger(__name__)
+    cl = RequestsApi()
+    cp_dir = os.path.join(contentpack_base_folder,os.environ.get("contentpack"),integration_payload_folder,integration_pattern)
+    files = glob.glob(cp_dir)
+    for file in files:
+        with open(file,'r') as f:
+            data = json.load(f)
+        f.close()
+        payload = json.dumps(data)
+        resp = cl.post("/api/integrations", data = payload).json()
+        logger.debug(resp)
+        success_status(resp)
